@@ -40,6 +40,10 @@ if [ -e $TARGET/var/cache/apt/archives/gnumach_* ] ; then
         extract gnumach
 fi
 
+if [ -e $TARGET/var/cache/apt/archives/libpthread-stubs0_* ] ; then
+        extract libpthread-stubs0
+fi
+
 x_feign_install dpkg
 if [ "$DEB_TARGET_GNU_SYSTEM" = "gnu" ] ; then
 	x_feign_install hurd
